@@ -126,8 +126,12 @@ mod gapbuffer;
 mod utils;
 mod iter;
 mod fast_str_tools;
-mod buffered;
-// mod params;
 
 pub use crate::jumprope::JumpRope;
+
+#[cfg_attr(doc_cfg, doc(cfg(feature = "buffered")))]
+#[cfg(feature = "buffered")]
+mod buffered;
+
+#[cfg(feature = "buffered")]
 pub use crate::buffered::JumpRopeBuf;
\ No newline at end of file
